@@ -5,10 +5,15 @@ class AsiaCell:
     def login(self,user):
 
         headers = {
-            'DeviceID': '8bfb8eabcf16425b78912b69918dcde3',
-        }
+            'DeviceID': '6cf77389aa2b259c2951a12b3bad0175',
+            }
 
-        r = post("https://app.asiacell.com/api/v1/login?lang=ar",headers=headers,json={"username":user,"captchaCode":""})
+        r1 = post("https://www.asiacell.com/api/v1/captcha?lang=ar",headers=headers,json={})
+        img = r1.json()['captcha']['originSource']+r1.json()['captcha']['resourceUrl']
+
+        cap = get(f"https://alshbg.ml/test/asiacell/cap.php?url={img}")
+
+        r = post("https://www.asiacell.com/api/v1/loginV2?lang=ar",headers=headers,json={"username":user,"captchaCode":cap.text})
 
         PID = r.json()['nextUrl'].split("PID=")[1]
 
@@ -16,7 +21,7 @@ class AsiaCell:
 
     def smsvalidation(self, PID, password):
         tokh = {
-            'DeviceID': '8bfb8eabcf16425b78912b69918dcde3',
+            'DeviceID': '6cf77389aa2b259c2951a12b3bad0175',
         }
 
         tokg = post('https://app.asiacell.com/api/v1/smsvalidation?lang=ar',headers=tokh,json={"PID":PID,"passcode":password})
@@ -25,7 +30,7 @@ class AsiaCell:
     def home(self, access_token):
         headers_g = {
             'Authorization': 'Bearer '+access_token,
-            'DeviceID': '8bfb8eabcf16425b78912b69918dcde3',
+            'DeviceID': '6cf77389aa2b259c2951a12b3bad0175',
      }
         r = get('https://app.asiacell.com/api/v1/home?lang=ar',headers=headers_g).json()
 
@@ -34,7 +39,7 @@ class AsiaCell:
     def profile(self, access_token):
         headers_g = {
             'Authorization': 'Bearer '+access_token,
-            'DeviceID': '8bfb8eabcf16425b78912b69918dcde3',
+            'DeviceID': '6cf77389aa2b259c2951a12b3bad0175',
      }
         r = get('https://www.asiacell.com/api/v1/profile?lang=ar',headers=headers_g).json()
 
@@ -43,7 +48,7 @@ class AsiaCell:
     def transformation(self, amount, member, access_token):
         tokh = {
             'Authorization': 'Bearer '+access_token,
-            'DeviceID': '8bfb8eabcf16425b78912b69918dcde3',
+            'DeviceID': '6cf77389aa2b259c2951a12b3bad0175',
         }
 
         tokg = post('https://www.asiacell.com/api/v1/credit-transfer/start?lang=ar',headers=tokh,json={"amount":amount,"receiverMsisdn":member})
@@ -53,9 +58,19 @@ class AsiaCell:
     def donebg(self, PID, password, access_token):
         tokh = {
             'Authorization': 'Bearer '+access_token,
-            'DeviceID': '8bfb8eabcf16425b78912b69918dcde3',
+            'DeviceID': '6cf77389aa2b259c2951a12b3bad0175',
         }
 
         tokg = post('https://www.asiacell.com/api/v1/credit-transfer/do-transfer?lang=ar',headers=tokh,json={"PID":PID,"passcode":password})
 
+        return tokg.json()
+
+    def recharge(self, resud, access_token):
+        tokh = {
+            'Authorization': 'Bearer '+access_token,
+            'DeviceID': '6cf77389aa2b259c2951a12b3bad0175',
+        }
+
+        tokg = post('https://www.asiacell.com/api/v1/top-up?lang=ar',headers=tokh,json={"iccid":null,"voucher":resud,"msisdn":null,"rechargeType":1})
+
         return tokg.json()
\ No newline at end of file
